@@ -1,6 +1,5 @@
 ﻿from __future__ import annotations
 
-import logging
 import threading
 from typing import Dict, Tuple, Callable, List, Optional
 
@@ -188,21 +187,24 @@ class API:
             LoginError: 登入失敗。
             WrongIDorPassword: 帳號或密碼錯誤。
             OnlySecureConnection: 只能使用安全連線。
+            ResetYourContactEmail: 請先至信箱設定連絡信箱。
 
         範例::
 
-            from PyPtt
+            import PyPtt
             ptt_bot = PyPtt.API()
 
             try:
                 ptt_bot.login(
                     ptt_id='ptt_id', ptt_pw='ptt_pw', kick_other_session=True)
             except PyPtt.LoginError:
-                log.py.info('登入失敗')
+                print('登入失敗')
             except PyPtt.WrongIDorPassword:
-                log.py.info('帳號密碼錯誤')
-            except PyPtt.LoginTooOften:
-                log.py.info('請稍等一下再登入')
+                print('帳號密碼錯誤')
+            except PyPtt.OnlySecureConnection:
+                print('只能使用安全連線')
+            except PyPtt.ResetYourContactEmail:
+                print('請先至信箱設定連絡信箱')
 
         """
 
@@ -222,8 +224,10 @@ class API:
 
             try:
                 # .. login ..
+                # .. do something ..
             finally:
                 ptt_bot.logout()
+
         """
 
         _api_loginout.logout(self)
